@@ -172,3 +172,25 @@ def invalid_hosts(hosts):
     the inverse of valid_hosts()
     """
     return not valid_hosts(hosts)
+
+
+def join(parent, child):
+    """
+    properly joins parent and child
+    """
+    return '%s%s' % (parent if parent == '/' else parent + '/', child)
+
+
+def split(path):
+    """
+    splits path into parent, child
+    """
+    if path == '/':
+        return ('/', None)
+
+    parent, child = path.rsplit('/', 1)
+
+    if parent == '':
+        parent = '/'
+
+    return (parent, child)
